mercurial/crecord.py
branchstable
changeset 27530 ba30ef5bba95
parent 27529 940cedaee988
child 27532 1be02894dd6f
--- a/mercurial/crecord.py	Tue Dec 15 15:56:10 2015 -0800
+++ b/mercurial/crecord.py	Tue Dec 15 16:00:06 2015 -0800
@@ -43,8 +43,9 @@
         import wcurses as curses
         curses.error
     except ImportError:
-        # wcurses is not shipped on Windows by default
-        pass
+        # wcurses is not shipped on Windows by default, or python is not
+        # compiled with curses
+        curses = False
 
 try:
     curses